;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "consult" "3.4"
  "Search and navigate via completing-read."
  '((emacs  "29.1")
    (compat "30"))
  :url "https://github.com/minad/consult"
  :commit "f8c2ef57e83af3d45e345e5c14089f2f9973682b"
  :revdesc "3.4-0-gf8c2ef57e83a"
  :keywords '("matching" "files" "completion")
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
